@@ -22,7 +22,7 @@ def pixel(x, y):
     checkForIssues(x)
     checkForIssues(y)
     if (platform == "darwin"):
-        return (tuple(os.popen("static/get-pixel-color " + str(x) + " " + str(y)).read()))
+        return (tuple(os.popen("/static/get-pixel-color " + str(x) + " " + str(y)).read()))
     elif (platform == "win32" or platform == "linux" or platform == "linux2"):
         # screenshot the area, saving to a temporary folder based on the OS
         if (platform == "win32"):
